StateRef class

Constructors

StateRef(State<StatefulWidget> _state)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose<T extends StateModel>() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read<T extends StateModel>() → T?
toString() String
A string representation of this object.
inherited
watch<T extends StateModel>(T create()) → T

Operators

operator ==(Object other) bool
The equality operator.
inherited